# sdkms/v1.AppsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_app**](AppsApi.md#create_app) | **POST** /sys/v1/apps | Create a new application
[**delete_app**](AppsApi.md#delete_app) | **DELETE** /sys/v1/apps/{app-id} | Delete application
[**get_app**](AppsApi.md#get_app) | **GET** /sys/v1/apps/{app-id} | Get a specific application
[**get_apps**](AppsApi.md#get_apps) | **GET** /sys/v1/apps | Get all applications
[**get_credential**](AppsApi.md#get_credential) | **GET** /sys/v1/apps/{app-id}/credential | Get a specific application&#39;s credential
[**regenerate_api_key**](AppsApi.md#regenerate_api_key) | **POST** /sys/v1/apps/{app-id}/reset_secret | Regenerate API key
[**update_app**](AppsApi.md#update_app) | **PATCH** /sys/v1/apps/{app-id} | Update an application


# **create_app**
> App create_app(body)

Create a new application

Create a new application with the specified properties.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.AppRequest() # AppRequest | Properties of application to create

try: 
    # Create a new application
    api_response = api_instance.create_app(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AppsApi->create_app: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**AppRequest**](AppRequest.md)| Properties of application to create | 

### Return type

[**App**](App.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_app**
> delete_app(app_id)

Delete application

Remove an application from SDKMS.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
app_id = 'app_id_example' # str | Application Identifier

try: 
    # Delete application
    api_instance.delete_app(app_id)
except ApiException as e:
    print("Exception when calling AppsApi->delete_app: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **str**| Application Identifier | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_app**
> App get_app(app_id)

Get a specific application

Look up an application by application ID.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
app_id = 'app_id_example' # str | Application Identifier

try: 
    # Get a specific application
    api_response = api_instance.get_app(app_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AppsApi->get_app: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **str**| Application Identifier | 

### Return type

[**App**](App.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_apps**
> list[App] get_apps(group_id=group_id, sort=sort, start=start, limit=limit, offset=offset)

Get all applications

Get details of all applications the current user has access to.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Only retrieve applications in the specified group. (optional)
sort = 'sort_example' # str | This specifies the property (`app_id` only, for now) and order (ascending or descending) with which to sort the apps. By default, apps are sorted by `app_id` in ascending order. The syntax is \"<property>:[asc|desc]\" (e.g. \"app_id:desc\") or just \"<property>\" (ascending order by default).  (optional)
start = 'start_example' # str | If provided, this must be a value of the property specified in `sort`. Returned apps will begin just above or just below this value (for asc/desc order resp.).  (optional)
limit = 56 # int | Maximum number of apps to return. If not provided, the limit is 100. (optional)
offset = 56 # int | Number of apps past `start` to skip. (optional)

try: 
    # Get all applications
    api_response = api_instance.get_apps(group_id=group_id, sort=sort, start=start, limit=limit, offset=offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AppsApi->get_apps: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Only retrieve applications in the specified group. | [optional] 
 **sort** | **str**| This specifies the property (&#x60;app_id&#x60; only, for now) and order (ascending or descending) with which to sort the apps. By default, apps are sorted by &#x60;app_id&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;app_id:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default).  | [optional] 
 **start** | **str**| If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned apps will begin just above or just below this value (for asc/desc order resp.).  | [optional] 
 **limit** | **int**| Maximum number of apps to return. If not provided, the limit is 100. | [optional] 
 **offset** | **int**| Number of apps past &#x60;start&#x60; to skip. | [optional] 

### Return type

[**list[App]**](App.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_credential**
> AppCredentialResponse get_credential(app_id)

Get a specific application's credential

Retrieve the authentication credential (API key or certificate) for a particular application. Only users who are an administrator of at least one of the application's groups can retrieve the credential.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
app_id = 'app_id_example' # str | Application Identifier

try: 
    # Get a specific application's credential
    api_response = api_instance.get_credential(app_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AppsApi->get_credential: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **str**| Application Identifier | 

### Return type

[**AppCredentialResponse**](AppCredentialResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **regenerate_api_key**
> App regenerate_api_key(app_id, body)

Regenerate API key

Create a new API key for an application. An application may only have one valid API key at a time, so performing this action will invalidate all old API keys. This does not invalidate existing sessions, so any applications with an existing open session will be able to continue operating with their old session until those sessions expire. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
app_id = 'app_id_example' # str | Application Identifier
body = sdkms/v1.AppResetSecretRequest() # AppResetSecretRequest | Decryption request

try: 
    # Regenerate API key
    api_response = api_instance.regenerate_api_key(app_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AppsApi->regenerate_api_key: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **str**| Application Identifier | 
 **body** | [**AppResetSecretRequest**](AppResetSecretRequest.md)| Decryption request | 

### Return type

[**App**](App.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_app**
> App update_app(app_id, body)

Update an application

Change an application's properties, such as name, description, or group membership.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.AppsApi(sdkms/v1.ApiClient(configuration))
app_id = 'app_id_example' # str | Application Identifier
body = sdkms/v1.AppRequest() # AppRequest | Properties of application to create

try: 
    # Update an application
    api_response = api_instance.update_app(app_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AppsApi->update_app: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **str**| Application Identifier | 
 **body** | [**AppRequest**](AppRequest.md)| Properties of application to create | 

### Return type

[**App**](App.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

