# sdkms/v1.GroupsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**azure_vaults**](GroupsApi.md#azure_vaults) | **POST** /sys/v1/groups/hmg/azure_vaults | List all Azure Key Vaults available to back a group
[**check_group_hmg**](GroupsApi.md#check_group_hmg) | **POST** /sys/v1/groups/{group-id}/hmg/check | Check the HMG configuration of a group
[**check_hmg**](GroupsApi.md#check_hmg) | **POST** /sys/v1/groups/hmg/check | Check a HMG configuration
[**create_group**](GroupsApi.md#create_group) | **POST** /sys/v1/groups | Create new group
[**delete_group**](GroupsApi.md#delete_group) | **DELETE** /sys/v1/groups/{group-id} | Delete group
[**get_group**](GroupsApi.md#get_group) | **GET** /sys/v1/groups/{group-id} | Get a specific group
[**get_groups**](GroupsApi.md#get_groups) | **GET** /sys/v1/groups | Get all groups
[**scan_hmg**](GroupsApi.md#scan_hmg) | **POST** /sys/v1/groups/{group-id}/hmg/scan | Scan all keys from the external source for a particular group
[**update_group**](GroupsApi.md#update_group) | **PATCH** /sys/v1/groups/{group-id} | Update group


# **azure_vaults**
> list[AzureKeyVaultResponse] azure_vaults()

List all Azure Key Vaults available to back a group

Given an Azure HMG configuration, fetch a list of available Azure key vaults which can be used to back a group. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))

try: 
    # List all Azure Key Vaults available to back a group
    api_response = api_instance.azure_vaults()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling GroupsApi->azure_vaults: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**list[AzureKeyVaultResponse]**](AzureKeyVaultResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **check_group_hmg**
> check_group_hmg(group_id)

Check the HMG configuration of a group

Check that the HMG configuration for a particular group is valid and reachable.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Group Identifier

try: 
    # Check the HMG configuration of a group
    api_instance.check_group_hmg(group_id)
except ApiException as e:
    print("Exception when calling GroupsApi->check_group_hmg: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Group Identifier | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **check_hmg**
> check_hmg(body)

Check a HMG configuration

Check that the HMG configuration provided is valid and reachable.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.HmgConfig() # HmgConfig | Request to check validity and reachability of an external configuration

try: 
    # Check a HMG configuration
    api_instance.check_hmg(body)
except ApiException as e:
    print("Exception when calling GroupsApi->check_hmg: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**HmgConfig**](HmgConfig.md)| Request to check validity and reachability of an external configuration | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_group**
> Group create_group(body)

Create new group

Create a new group with the specified properties.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.GroupRequest() # GroupRequest | Name of group

try: 
    # Create new group
    api_response = api_instance.create_group(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling GroupsApi->create_group: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**GroupRequest**](GroupRequest.md)| Name of group | 

### Return type

[**Group**](Group.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_group**
> delete_group(group_id)

Delete group

Remove a group from SDKMS.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Group Identifier

try: 
    # Delete group
    api_instance.delete_group(group_id)
except ApiException as e:
    print("Exception when calling GroupsApi->delete_group: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Group Identifier | 

### Return type

void (empty response body)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_group**
> Group get_group(group_id)

Get a specific group

Look up a specific group by group ID.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Group Identifier

try: 
    # Get a specific group
    api_response = api_instance.get_group(group_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling GroupsApi->get_group: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Group Identifier | 

### Return type

[**Group**](Group.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_groups**
> list[Group] get_groups()

Get all groups

Get detailed information about all groups the authenticated User or authenticated Application belongs to.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))

try: 
    # Get all groups
    api_response = api_instance.get_groups()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling GroupsApi->get_groups: %s\n" % e)
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**list[Group]**](Group.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **scan_hmg**
> list[KeyObject] scan_hmg(group_id)

Scan all keys from the external source for a particular group

For a group backed by an external source, scan the external source for changes since the last scan, and accordingly update the group. This includes creating virtual keys for new keys found, marking the virtual keys of missing keys as destroyed, and updating the metadata of changed keys. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Group Identifier

try: 
    # Scan all keys from the external source for a particular group
    api_response = api_instance.scan_hmg(group_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling GroupsApi->scan_hmg: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Group Identifier | 

### Return type

[**list[KeyObject]**](KeyObject.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_group**
> Group update_group(group_id, body)

Update group

Change a group's properties.

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.GroupsApi(sdkms/v1.ApiClient(configuration))
group_id = 'group_id_example' # str | Group Identifier
body = sdkms/v1.GroupRequest() # GroupRequest | Name of group

try: 
    # Update group
    api_response = api_instance.update_group(group_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling GroupsApi->update_group: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **str**| Group Identifier | 
 **body** | [**GroupRequest**](GroupRequest.md)| Name of group | 

### Return type

[**Group**](Group.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

